# encoding: utf-8

module Mysqlcollector
  class Influxdb
    def initialize
      @influx = InfluxDB::Client.new(host:     $config[:influx_host],
                                     database: $config[:influx_database],
                                     username: $config[:influx_user],
                                     password: $config[:influx_password],
                                     retry:    10)
    end

    def vacuum(values)
      # Validate it is array and have values?
      return nil if values.nil?
      return nil unless values.is_a?(Array)

      # Remove empty variable on array of array:
      values.reject{ |a| a.all? {|e| e.nil? || e.strip.empty? }}
    end

    def data(type, metrics, instance)
      # Validate a variable metrics has values on array?
      return nil if type.nil?
      return nil if instance.nil?
      return nil if metrics.nil?
      return nil if metrics.count == 0
      return nil unless metrics.is_a?(Array)

      # Send value:
      values = []
      metrics.each do |metric, value|
        if value.is_number?
          values << {
            series: type,
            values: { value: Float(value) },
            tags: { metric: metric,
                    instance: instance }
          }

          Mysqlcollector::Log.new.debug("InfluxDB Values: #{values.last}");
        end
      end
      values
    end

    def send(type, metrics)
      metrics = vacuum(metrics)
      metrics = data(type, metrics, $config[:alias])

      return nil unless metrics.is_a?(Array)

      @influx.write_points(metrics)
    rescue Exception => error
      Mysqlcollector::Log.new.error(error.message)
    end
  end
end
